#[non_exhaustive]pub enum IssuingCardFraudWarningType {
CardTestingExposure,
FraudDisputeFiled,
ThirdPartyReported,
UserIndicatedFraud,
Unknown(String),
}Expand description
The type of fraud warning that most recently took place on this card. This field updates with every new fraud warning, so the value changes over time. If populated, cancel and reissue the card.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CardTestingExposure
FraudDisputeFiled
ThirdPartyReported
UserIndicatedFraud
Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter.
Implementations