#[non_exhaustive]pub enum CreateIssuingAuthorizationRiskAssessmentCardTestingRiskLevel {
Elevated,
Highest,
Low,
Normal,
NotAssessed,
Unknown,
_Unknown(String),
}Expand description
The likelihood that this authorization is associated with card testing activity. This is assessed by evaluating decline activity over the last hour.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Elevated
Highest
Low
Normal
NotAssessed
Unknown
_Unknown(String)
An unrecognized value from Stripe. Should not be used as a request parameter. This variant is prefixed with an underscore to avoid conflicts with Stripe’s ‘Unknown’ variant.
Implementations