CaptureIssuingAuthorization

Struct CaptureIssuingAuthorization 

pub struct CaptureIssuingAuthorization { /* private fields */ }
Capture a test-mode authorization.

Implementations

Source

impl CaptureIssuingAuthorization

pub fn new(authorization: impl Into<String>) -> Self

Construct a new CaptureIssuingAuthorization.

pub fn capture_amount(self, capture_amount: impl Into<i64>) -> Self

The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the smallest currency unit.

pub fn close_authorization(self, close_authorization: impl Into<bool>) -> Self

Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn purchase_details( self, purchase_details: impl Into<CaptureIssuingAuthorizationPurchaseDetails>, ) -> Self

Additional purchase information that is optionally provided by the merchant.

Source

impl CaptureIssuingAuthorization

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.