CreateIssuingAuthorization

Struct CreateIssuingAuthorization 

pub struct CreateIssuingAuthorization { /* private fields */ }
Create a test-mode authorization.

Implementations

Source

impl CreateIssuingAuthorization

pub fn new(card: impl Into<String>) -> Self

Construct a new CreateIssuingAuthorization.

pub fn amount(self, amount: impl Into<i64>) -> Self

The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the smallest currency unit.

pub fn amount_details( self, amount_details: impl Into<CreateIssuingAuthorizationAmountDetails>, ) -> Self

Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.

pub fn authorization_method( self, authorization_method: impl Into<IssuingAuthorizationAuthorizationMethod>, ) -> Self

How the card details were provided. Defaults to online.

pub fn currency(self, currency: impl Into<Currency>) -> Self

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn fleet(self, fleet: impl Into<CreateIssuingAuthorizationFleet>) -> Self

Fleet-specific information for authorizations using Fleet cards.

pub fn fraud_disputability_likelihood( self, fraud_disputability_likelihood: impl Into<CreateIssuingAuthorizationFraudDisputabilityLikelihood>, ) -> Self

Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.

pub fn fuel(self, fuel: impl Into<CreateIssuingAuthorizationFuel>) -> Self

Information about fuel that was purchased with this transaction.

pub fn is_amount_controllable( self, is_amount_controllable: impl Into<bool>, ) -> Self

If set true, you may provide amount to control how much to hold for the authorization.

pub fn merchant_amount(self, merchant_amount: impl Into<i64>) -> Self

The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the smallest currency unit.

pub fn merchant_currency(self, merchant_currency: impl Into<Currency>) -> Self

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.

pub fn merchant_data( self, merchant_data: impl Into<CreateIssuingAuthorizationMerchantData>, ) -> Self

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.

pub fn network_data( self, network_data: impl Into<CreateIssuingAuthorizationNetworkData>, ) -> Self

Details about the authorization, such as identifiers, set by the card network.

pub fn risk_assessment( self, risk_assessment: impl Into<CreateIssuingAuthorizationRiskAssessment>, ) -> Self

Stripe’s assessment of the fraud risk for this authorization.

pub fn verification_data( self, verification_data: impl Into<CreateIssuingAuthorizationVerificationData>, ) -> Self

Verifications that Stripe performed on information that the cardholder provided to the merchant.

pub fn wallet(self, wallet: impl Into<CreateIssuingAuthorizationWallet>) -> Self

The digital wallet used for this transaction. One of apple_pay, google_pay, or samsung_pay. Will populate as null when no digital wallet was utilized.

Source

impl CreateIssuingAuthorization

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.