CreateIssuingAuthorizationFleet

Struct CreateIssuingAuthorizationFleet 

pub struct CreateIssuingAuthorizationFleet {
    pub cardholder_prompt_data: Option<FleetCardholderPromptDataSpecs>,
    pub purchase_type: Option<CreateIssuingAuthorizationFleetPurchaseType>,
    pub reported_breakdown: Option<FleetReportedBreakdownSpecs>,
    pub service_type: Option<CreateIssuingAuthorizationFleetServiceType>,
}
Fleet-specific information for authorizations using Fleet cards.

Fields

cardholder_prompt_data: Option<FleetCardholderPromptDataSpecs>

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.

purchase_type: Option<CreateIssuingAuthorizationFleetPurchaseType>

The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.

reported_breakdown: Option<FleetReportedBreakdownSpecs>

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.

service_type: Option<CreateIssuingAuthorizationFleetServiceType>

The type of fuel service. One of non_fuel_transaction, full_service, or self_service.

Implementations