pub struct CreateIssuingAuthorizationNetworkData {
pub acquiring_institution_id: Option<String>,
}Expand description
Details about the authorization, such as identifiers, set by the card network.
Fields
acquiring_institution_id: Option<String>Identifier assigned to the acquirer by the card network.
Implementations