CreateIssuingAuthorizationRiskAssessment

Struct CreateIssuingAuthorizationRiskAssessment 

pub struct CreateIssuingAuthorizationRiskAssessment {
    pub card_testing_risk: Option<CreateIssuingAuthorizationRiskAssessmentCardTestingRisk>,
    pub fraud_risk: Option<CreateIssuingAuthorizationRiskAssessmentFraudRisk>,
    pub merchant_dispute_risk: Option<CreateIssuingAuthorizationRiskAssessmentMerchantDisputeRisk>,
}
Stripe’s assessment of the fraud risk for this authorization.

Fields

card_testing_risk: Option<CreateIssuingAuthorizationRiskAssessmentCardTestingRisk>

Stripe’s assessment of this authorization’s likelihood of being card testing activity.

fraud_risk: Option<CreateIssuingAuthorizationRiskAssessmentFraudRisk>

Stripe’s assessment of this authorization’s likelihood to be fraudulent.

merchant_dispute_risk: Option<CreateIssuingAuthorizationRiskAssessmentMerchantDisputeRisk>

The dispute risk of the merchant (the seller on a purchase) on an authorization based on all Stripe Issuing activity.

Implementations