pub struct DeclineIssuingAuthorization { /* private fields */ }Expand description
[Deprecated] Declines a pending Issuing Authorization object.
This request should be made within the timeout window of the real time authorization flow.
This method is deprecated.
Instead, respond directly to the webhook request to decline an authorization.
Implementations
Sourceimpl DeclineIssuingAuthorization
impl DeclineIssuingAuthorization
Sourcepub fn new(authorization: impl Into<IssuingAuthorizationId>) -> Self
pub fn new(authorization: impl Into<IssuingAuthorizationId>) -> Self
Construct a new DeclineIssuingAuthorization.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
Sourceimpl DeclineIssuingAuthorization
impl DeclineIssuingAuthorization
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.