pub struct FinalizeAmountIssuingAuthorization { /* private fields */ }Expand description
Finalize the amount on an Authorization prior to capture, when the initial authorization was for an estimated amount.
Implementations
Sourceimpl FinalizeAmountIssuingAuthorization
impl FinalizeAmountIssuingAuthorization
Sourcepub fn new(
authorization: impl Into<String>,
final_amount: impl Into<i64>,
) -> Self
pub fn new( authorization: impl Into<String>, final_amount: impl Into<i64>, ) -> Self
Construct a new FinalizeAmountIssuingAuthorization.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn fleet(
self,
fleet: impl Into<FinalizeAmountIssuingAuthorizationFleet>,
) -> Self
pub fn fleet( self, fleet: impl Into<FinalizeAmountIssuingAuthorizationFleet>, ) -> Self
Fleet-specific information for authorizations using Fleet cards.
Sourcepub fn fuel(
self,
fuel: impl Into<FinalizeAmountIssuingAuthorizationFuel>,
) -> Self
pub fn fuel( self, fuel: impl Into<FinalizeAmountIssuingAuthorizationFuel>, ) -> Self
Information about fuel that was purchased with this transaction.
Sourceimpl FinalizeAmountIssuingAuthorization
impl FinalizeAmountIssuingAuthorization
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.