pub struct IncrementIssuingAuthorization { /* private fields */ }Expand description
Increment a test-mode Authorization.
Implementations
Sourceimpl IncrementIssuingAuthorization
impl IncrementIssuingAuthorization
Sourcepub fn new(
authorization: impl Into<String>,
increment_amount: impl Into<i64>,
) -> Self
pub fn new( authorization: impl Into<String>, increment_amount: impl Into<i64>, ) -> Self
Construct a new IncrementIssuingAuthorization.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn is_amount_controllable(
self,
is_amount_controllable: impl Into<bool>,
) -> Self
pub fn is_amount_controllable( self, is_amount_controllable: impl Into<bool>, ) -> Self
If set true, you may provide amount to control how much to hold for the authorization.
Sourceimpl IncrementIssuingAuthorization
impl IncrementIssuingAuthorization
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.