CreateIssuingCard

Struct CreateIssuingCard 

pub struct CreateIssuingCard { /* private fields */ }
Creates an Issuing Card object.

Implementations

Source

impl CreateIssuingCard

pub fn new( currency: impl Into<Currency>, type_: impl Into<IssuingCardType>, ) -> Self

Construct a new CreateIssuingCard.

pub fn cardholder(self, cardholder: impl Into<String>) -> Self

The Cardholder object with which the card will be associated.

pub fn exp_month(self, exp_month: impl Into<i64>) -> Self

The desired expiration month (1-12) for this card if specifying a custom expiration date.

pub fn exp_year(self, exp_year: impl Into<i64>) -> Self

The desired 4-digit expiration year for this card if specifying a custom expiration date.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn financial_account(self, financial_account: impl Into<String>) -> Self

The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.

pub fn lifecycle_controls( self, lifecycle_controls: impl Into<CreateIssuingCardLifecycleControls>, ) -> Self

Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our documentation for more details.

pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.

pub fn personalization_design( self, personalization_design: impl Into<String>, ) -> Self

The personalization design object belonging to this card.

pub fn pin(self, pin: impl Into<EncryptedPinParam>) -> Self

The desired PIN for this card.

pub fn replacement_for(self, replacement_for: impl Into<String>) -> Self

The card this is meant to be a replacement for (if any).

pub fn replacement_reason( self, replacement_reason: impl Into<CreateIssuingCardReplacementReason>, ) -> Self

If replacement_for is specified, this should indicate why that card is being replaced.

pub fn second_line(self, second_line: impl Into<String>) -> Self

The second line to print on the card. Max length: 24 characters.

pub fn shipping(self, shipping: impl Into<CreateIssuingCardShipping>) -> Self

The address where the card will be shipped.

pub fn spending_controls( self, spending_controls: impl Into<CreateIssuingCardSpendingControls>, ) -> Self

Rules that control spending for this card. Refer to our documentation for more details.

pub fn status(self, status: impl Into<CreateIssuingCardStatus>) -> Self

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to inactive.

Source

impl CreateIssuingCard

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.