pub struct CreateIssuingCardLifecycleControls {
pub cancel_after: CreateIssuingCardLifecycleControlsCancelAfter,
}Expand description
Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our documentation for more details.
Fields
cancel_after: CreateIssuingCardLifecycleControlsCancelAfterCancels the card after the specified conditions are met.
Implementations
Sourceimpl CreateIssuingCardLifecycleControls
impl CreateIssuingCardLifecycleControls
pub fn new( cancel_after: impl Into<CreateIssuingCardLifecycleControlsCancelAfter>, ) -> Self