pub struct CreateIssuingCardSpendingControls {
pub allowed_card_presences: Option<Vec<CreateIssuingCardSpendingControlsAllowedCardPresences>>,
pub allowed_categories: Option<Vec<CreateIssuingCardSpendingControlsAllowedCategories>>,
pub allowed_merchant_countries: Option<Vec<String>>,
pub blocked_card_presences: Option<Vec<CreateIssuingCardSpendingControlsBlockedCardPresences>>,
pub blocked_categories: Option<Vec<CreateIssuingCardSpendingControlsBlockedCategories>>,
pub blocked_merchant_countries: Option<Vec<String>>,
pub spending_limits: Option<Vec<CreateIssuingCardSpendingControlsSpendingLimits>>,
}Expand description
Rules that control spending for this card. Refer to our documentation for more details.
Fields
allowed_card_presences: Option<Vec<CreateIssuingCardSpendingControlsAllowedCardPresences>>Array of card presence statuses from which authorizations will be allowed.
Possible options are present, not_present.
All other statuses will be blocked.
Cannot be set with blocked_card_presences.
Provide an empty value to unset this control.
allowed_categories: Option<Vec<CreateIssuingCardSpendingControlsAllowedCategories>>Array of strings containing categories of authorizations to allow.
All other categories will be blocked.
Cannot be set with blocked_categories.
allowed_merchant_countries: Option<Vec<String>>Array of strings containing representing countries from which authorizations will be allowed.
Authorizations from merchants in all other countries will be declined.
Country codes should be ISO 3166 alpha-2 country codes (e.g.
US).
Cannot be set with blocked_merchant_countries.
Provide an empty value to unset this control.
blocked_card_presences: Option<Vec<CreateIssuingCardSpendingControlsBlockedCardPresences>>Array of card presence statuses from which authorizations will be declined.
Possible options are present, not_present.
Cannot be set with allowed_card_presences.
Provide an empty value to unset this control.
blocked_categories: Option<Vec<CreateIssuingCardSpendingControlsBlockedCategories>>Array of strings containing categories of authorizations to decline.
All other categories will be allowed.
Cannot be set with allowed_categories.
blocked_merchant_countries: Option<Vec<String>>Array of strings containing representing countries from which authorizations will be declined.
Country codes should be ISO 3166 alpha-2 country codes (e.g.
US).
Cannot be set with allowed_merchant_countries.
Provide an empty value to unset this control.
spending_limits: Option<Vec<CreateIssuingCardSpendingControlsSpendingLimits>>Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its replacement_for card and that card’s replacement_for card, up the chain).
Implementations