ListIssuingCard

Struct ListIssuingCard 

pub struct ListIssuingCard { /* private fields */ }
Returns a list of Issuing Card objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.

Implementations

Source

impl ListIssuingCard

pub fn new() -> Self

Construct a new ListIssuingCard.

pub fn cardholder(self, cardholder: impl Into<String>) -> Self

Only return cards belonging to the Cardholder with the provided ID.

pub fn created(self, created: impl Into<RangeQueryTs>) -> Self

Only return cards that were issued during the given date interval.

pub fn ending_before(self, ending_before: impl Into<String>) -> Self

A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.

pub fn exp_month(self, exp_month: impl Into<i64>) -> Self

Only return cards that have the given expiration month.

pub fn exp_year(self, exp_year: impl Into<i64>) -> Self

Only return cards that have the given expiration year.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn last4(self, last4: impl Into<String>) -> Self

Only return cards that have the given last four digits.

pub fn limit(self, limit: impl Into<i64>) -> Self

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.

pub fn personalization_design( self, personalization_design: impl Into<String>, ) -> Self

pub fn starting_after(self, starting_after: impl Into<String>) -> Self

A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.

pub fn status(self, status: impl Into<IssuingCardStatus>) -> Self

Only return cards that have the given status. One of active, inactive, or canceled.

pub fn type_(self, type_: impl Into<IssuingCardType>) -> Self

Only return cards that have the given type. One of virtual or physical.

Source

impl ListIssuingCard

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.

pub fn paginate(&self) -> ListPaginator<List<IssuingCard>>