UpdateIssuingCard

Struct UpdateIssuingCard 

pub struct UpdateIssuingCard { /* private fields */ }
Updates the specified Issuing Card object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.

Implementations

Source

impl UpdateIssuingCard

pub fn new(card: impl Into<IssuingCardId>) -> Self

Construct a new UpdateIssuingCard.

pub fn cancellation_reason( self, cancellation_reason: impl Into<UpdateIssuingCardCancellationReason>, ) -> Self

Reason why the status of this card is canceled.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.

pub fn personalization_design( self, personalization_design: impl Into<String>, ) -> Self

pub fn pin(self, pin: impl Into<EncryptedPinParam>) -> Self

The desired new PIN for this card.

pub fn shipping(self, shipping: impl Into<UpdateIssuingCardShipping>) -> Self

Updated shipping information for the card.

pub fn spending_controls( self, spending_controls: impl Into<UpdateIssuingCardSpendingControls>, ) -> Self

Rules that control spending for this card. Refer to our documentation for more details.

pub fn status(self, status: impl Into<IssuingCardStatus>) -> Self

Dictates whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to inactive. If this card is being canceled because it was lost or stolen, this information should be provided as cancellation_reason.

Source

impl UpdateIssuingCard

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.