CreateIssuingCardholder

Struct CreateIssuingCardholder 

pub struct CreateIssuingCardholder { /* private fields */ }
Creates a new Issuing Cardholder object that can be issued cards.

Implementations

Source

impl CreateIssuingCardholder

pub fn new(billing: impl Into<BillingSpecs>, name: impl Into<String>) -> Self

Construct a new CreateIssuingCardholder.

pub fn company(self, company: impl Into<CompanyParam>) -> Self

Additional information about a company cardholder.

pub fn email(self, email: impl Into<String>) -> Self

The cardholder’s email address.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn individual(self, individual: impl Into<IndividualParam>) -> Self

Additional information about an individual cardholder.

pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.

pub fn phone_number(self, phone_number: impl Into<String>) -> Self

The cardholder’s phone number. This will be transformed to E.164 if it is not provided in that format already. This is required for all cardholders who will be creating EU cards. See the 3D Secure documentation for more details.

pub fn preferred_locales( self, preferred_locales: impl Into<Vec<IssuingCardholderPreferredLocales>>, ) -> Self

The cardholder’s preferred locales (languages), ordered by preference. Locales can be da, de, en, es, fr, it, pl, or sv. This changes the language of the 3D Secure flow and one-time password messages sent to the cardholder.

pub fn spending_controls( self, spending_controls: impl Into<CreateIssuingCardholderSpendingControls>, ) -> Self

Rules that control spending across this cardholder’s cards. Refer to our documentation for more details.

pub fn status(self, status: impl Into<CreateIssuingCardholderStatus>) -> Self

Specifies whether to permit authorizations on this cardholder’s cards. Defaults to active.

pub fn type_(self, type_: impl Into<IssuingCardholderType>) -> Self

One of individual or company. See Choose a cardholder type for more details.

Source

impl CreateIssuingCardholder

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.