pub struct CreateIssuingPersonalizationDesign { /* private fields */ }Expand description
Creates a personalization design object.
Implementations
Sourceimpl CreateIssuingPersonalizationDesign
impl CreateIssuingPersonalizationDesign
Sourcepub fn new(physical_bundle: impl Into<String>) -> Self
pub fn new(physical_bundle: impl Into<String>) -> Self
Construct a new CreateIssuingPersonalizationDesign.
Sourcepub fn card_logo(self, card_logo: impl Into<String>) -> Self
pub fn card_logo(self, card_logo: impl Into<String>) -> Self
The file for the card logo, for use with physical bundles that support card logos.
Must have a purpose value of issuing_logo.
Sourcepub fn carrier_text(self, carrier_text: impl Into<CarrierTextParam>) -> Self
pub fn carrier_text(self, carrier_text: impl Into<CarrierTextParam>) -> Self
Hash containing carrier text, for use with physical bundles that support carrier text.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn lookup_key(self, lookup_key: impl Into<String>) -> Self
pub fn lookup_key(self, lookup_key: impl Into<String>) -> Self
A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.
Sourcepub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
Sourcepub fn preferences(self, preferences: impl Into<PreferencesParam>) -> Self
pub fn preferences(self, preferences: impl Into<PreferencesParam>) -> Self
Information on whether this personalization design is used to create cards when one is not specified.
Sourcepub fn transfer_lookup_key(self, transfer_lookup_key: impl Into<bool>) -> Self
pub fn transfer_lookup_key(self, transfer_lookup_key: impl Into<bool>) -> Self
If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.
Sourceimpl CreateIssuingPersonalizationDesign
impl CreateIssuingPersonalizationDesign
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.