ListIssuingPersonalizationDesignPreferences

Struct ListIssuingPersonalizationDesignPreferences 

pub struct ListIssuingPersonalizationDesignPreferences {
    pub is_default: Option<bool>,
    pub is_platform_default: Option<bool>,
}
Only return personalization designs with the given preferences.

Fields

is_default: Option<bool>

Only return the personalization design that’s set as the default. A connected account uses the Connect platform’s default design if no personalization design is set as the default.

is_platform_default: Option<bool>

Only return the personalization design that is set as the Connect platform’s default. This parameter is only applicable to connected accounts.

Implementations