UpdateIssuingPersonalizationDesign

Struct UpdateIssuingPersonalizationDesign 

pub struct UpdateIssuingPersonalizationDesign { /* private fields */ }
Updates a card personalization object.

Implementations

Source

impl UpdateIssuingPersonalizationDesign

pub fn new( personalization_design: impl Into<IssuingPersonalizationDesignId>, ) -> Self

Construct a new UpdateIssuingPersonalizationDesign.

The file for the card logo, for use with physical bundles that support card logos. Must have a purpose value of issuing_logo.

pub fn carrier_text(self, carrier_text: impl Into<CarrierTextParam>) -> Self

Hash containing carrier text, for use with physical bundles that support carrier text.

pub fn expand(self, expand: impl Into<Vec<String>>) -> Self

Specifies which fields in the response should be expanded.

pub fn lookup_key(self, lookup_key: impl Into<String>) -> Self

A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.

pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.

pub fn name(self, name: impl Into<String>) -> Self

Friendly display name. Providing an empty string will set the field to null.

pub fn physical_bundle(self, physical_bundle: impl Into<String>) -> Self

The physical bundle object belonging to this personalization design.

pub fn preferences(self, preferences: impl Into<PreferencesParam>) -> Self

Information on whether this personalization design is used to create cards when one is not specified.

pub fn transfer_lookup_key(self, transfer_lookup_key: impl Into<bool>) -> Self

If set to true, will atomically remove the lookup key from the existing personalization design, and assign it to this personalization design.

Source

impl UpdateIssuingPersonalizationDesign

pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response.

pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>

Send the request and return the deserialized response, blocking until completion.