pub struct CreateForceCaptureIssuingTransaction { /* private fields */ }Expand description
Allows the user to capture an arbitrary amount, also known as a forced capture.
Implementations
Sourceimpl CreateForceCaptureIssuingTransaction
impl CreateForceCaptureIssuingTransaction
Sourcepub fn new(amount: impl Into<i64>, card: impl Into<String>) -> Self
pub fn new(amount: impl Into<i64>, card: impl Into<String>) -> Self
Construct a new CreateForceCaptureIssuingTransaction.
Sourcepub fn currency(self, currency: impl Into<Currency>) -> Self
pub fn currency(self, currency: impl Into<Currency>) -> Self
The currency of the capture. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn merchant_data(
self,
merchant_data: impl Into<CreateForceCaptureIssuingTransactionMerchantData>,
) -> Self
pub fn merchant_data( self, merchant_data: impl Into<CreateForceCaptureIssuingTransactionMerchantData>, ) -> Self
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
Sourcepub fn purchase_details(
self,
purchase_details: impl Into<CreateForceCaptureIssuingTransactionPurchaseDetails>,
) -> Self
pub fn purchase_details( self, purchase_details: impl Into<CreateForceCaptureIssuingTransactionPurchaseDetails>, ) -> Self
Additional purchase information that is optionally provided by the merchant.
Sourceimpl CreateForceCaptureIssuingTransaction
impl CreateForceCaptureIssuingTransaction
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.