pub struct CreateUnlinkedRefundIssuingTransaction { /* private fields */ }Expand description
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
Implementations
Sourceimpl CreateUnlinkedRefundIssuingTransaction
impl CreateUnlinkedRefundIssuingTransaction
Sourcepub fn new(amount: impl Into<i64>, card: impl Into<String>) -> Self
pub fn new(amount: impl Into<i64>, card: impl Into<String>) -> Self
Construct a new CreateUnlinkedRefundIssuingTransaction.
Sourcepub fn currency(self, currency: impl Into<Currency>) -> Self
pub fn currency(self, currency: impl Into<Currency>) -> Self
The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn merchant_data(
self,
merchant_data: impl Into<CreateUnlinkedRefundIssuingTransactionMerchantData>,
) -> Self
pub fn merchant_data( self, merchant_data: impl Into<CreateUnlinkedRefundIssuingTransactionMerchantData>, ) -> Self
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
Sourcepub fn purchase_details(
self,
purchase_details: impl Into<CreateUnlinkedRefundIssuingTransactionPurchaseDetails>,
) -> Self
pub fn purchase_details( self, purchase_details: impl Into<CreateUnlinkedRefundIssuingTransactionPurchaseDetails>, ) -> Self
Additional purchase information that is optionally provided by the merchant.
Sourceimpl CreateUnlinkedRefundIssuingTransaction
impl CreateUnlinkedRefundIssuingTransaction
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.