pub struct CreateUnlinkedRefundIssuingTransactionMerchantData {
pub category: Option<CreateUnlinkedRefundIssuingTransactionMerchantDataCategory>,
pub city: Option<String>,
pub country: Option<String>,
pub name: Option<String>,
pub network_id: Option<String>,
pub postal_code: Option<String>,
pub state: Option<String>,
pub terminal_id: Option<String>,
pub url: Option<String>,
}Expand description
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
Fields
category: Option<CreateUnlinkedRefundIssuingTransactionMerchantDataCategory>A categorization of the seller’s type of business. See our merchant categories guide for a list of possible values.
city: Option<String>City where the seller is located
country: Option<String>Country where the seller is located
name: Option<String>Name of the seller
network_id: Option<String>Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
postal_code: Option<String>Postal code where the seller is located
state: Option<String>State where the seller is located
terminal_id: Option<String>An ID assigned by the seller to the location of the sale.
url: Option<String>URL provided by the merchant on a 3DS request
Implementations