pub struct CreateUnlinkedRefundIssuingTransactionPurchaseDetails {
pub fleet: Option<CreateUnlinkedRefundIssuingTransactionPurchaseDetailsFleet>,
pub flight: Option<FlightSpecs>,
pub fuel: Option<CreateUnlinkedRefundIssuingTransactionPurchaseDetailsFuel>,
pub lodging: Option<LodgingSpecs>,
pub receipt: Option<Vec<ReceiptSpecs>>,
pub reference: Option<String>,
}Expand description
Additional purchase information that is optionally provided by the merchant.
Fields
fleet: Option<CreateUnlinkedRefundIssuingTransactionPurchaseDetailsFleet>Fleet-specific information for transactions using Fleet cards.
flight: Option<FlightSpecs>Information about the flight that was purchased with this transaction.
fuel: Option<CreateUnlinkedRefundIssuingTransactionPurchaseDetailsFuel>Information about fuel that was purchased with this transaction.
lodging: Option<LodgingSpecs>Information about lodging that was purchased with this transaction.
receipt: Option<Vec<ReceiptSpecs>>The line items in the purchase.
reference: Option<String>A merchant-specific order number.
Implementations