pub struct ListIssuingTransaction { /* private fields */ }Expand description
Returns a list of Issuing Transaction objects.
The objects are sorted in descending order by creation date, with the most recently created object appearing first.
Implementations
Sourceimpl ListIssuingTransaction
impl ListIssuingTransaction
Sourcepub fn card(self, card: impl Into<String>) -> Self
pub fn card(self, card: impl Into<String>) -> Self
Only return transactions that belong to the given card.
Sourcepub fn cardholder(self, cardholder: impl Into<String>) -> Self
pub fn cardholder(self, cardholder: impl Into<String>) -> Self
Only return transactions that belong to the given cardholder.
Sourcepub fn created(self, created: impl Into<RangeQueryTs>) -> Self
pub fn created(self, created: impl Into<RangeQueryTs>) -> Self
Only return transactions that were created during the given date interval.
Sourcepub fn ending_before(self, ending_before: impl Into<String>) -> Self
pub fn ending_before(self, ending_before: impl Into<String>) -> Self
A cursor for use in pagination.
ending_before is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn limit(self, limit: impl Into<i64>) -> Self
pub fn limit(self, limit: impl Into<i64>) -> Self
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
Sourcepub fn starting_after(self, starting_after: impl Into<String>) -> Self
pub fn starting_after(self, starting_after: impl Into<String>) -> Self
A cursor for use in pagination.
starting_after is an object ID that defines your place in the list.
For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
Sourcepub fn type_(self, type_: impl Into<IssuingTransactionType>) -> Self
pub fn type_(self, type_: impl Into<IssuingTransactionType>) -> Self
Only return transactions that have the given type. One of capture or refund.
Sourceimpl ListIssuingTransaction
impl ListIssuingTransaction
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.
pub fn paginate(&self) -> ListPaginator<List<IssuingTransaction>>