pub struct RefundIssuingTransaction { /* private fields */ }Expand description
Refund a test-mode Transaction.
Implementations
Sourceimpl RefundIssuingTransaction
impl RefundIssuingTransaction
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn refund_amount(self, refund_amount: impl Into<i64>) -> Self
pub fn refund_amount(self, refund_amount: impl Into<i64>) -> Self
The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the smallest currency unit.
Sourceimpl RefundIssuingTransaction
impl RefundIssuingTransaction
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.