pub struct UpdateIssuingTransaction { /* private fields */ }Expand description
Updates the specified Issuing Transaction object by setting the values of the parameters passed.
Any parameters not provided will be left unchanged.
Implementations
Sourceimpl UpdateIssuingTransaction
impl UpdateIssuingTransaction
Sourcepub fn new(transaction: impl Into<IssuingTransactionId>) -> Self
pub fn new(transaction: impl Into<IssuingTransactionId>) -> Self
Construct a new UpdateIssuingTransaction.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
Sourceimpl UpdateIssuingTransaction
impl UpdateIssuingTransaction
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.