pub struct CaptureIssuingAuthorization { /* private fields */ }Expand description
Capture a test-mode authorization.
Implementations
Sourceimpl CaptureIssuingAuthorization
impl CaptureIssuingAuthorization
Sourcepub fn new(authorization: impl Into<String>) -> Self
pub fn new(authorization: impl Into<String>) -> Self
Construct a new CaptureIssuingAuthorization.
Sourcepub fn capture_amount(self, capture_amount: impl Into<i64>) -> Self
pub fn capture_amount(self, capture_amount: impl Into<i64>) -> Self
The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the smallest currency unit.
Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn purchase_details(
self,
purchase_details: impl Into<CaptureIssuingAuthorizationPurchaseDetails>,
) -> Self
pub fn purchase_details( self, purchase_details: impl Into<CaptureIssuingAuthorizationPurchaseDetails>, ) -> Self
Additional purchase information that is optionally provided by the merchant.
Sourceimpl CaptureIssuingAuthorization
impl CaptureIssuingAuthorization
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.