pub struct CreateIssuingAuthorization { /* private fields */ }Expand description
Create a test-mode authorization.
Implementations
Sourceimpl CreateIssuingAuthorization
impl CreateIssuingAuthorization
Sourcepub fn amount(self, amount: impl Into<i64>) -> Self
pub fn amount(self, amount: impl Into<i64>) -> Self
The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the smallest currency unit.
Sourcepub fn amount_details(
self,
amount_details: impl Into<CreateIssuingAuthorizationAmountDetails>,
) -> Self
pub fn amount_details( self, amount_details: impl Into<CreateIssuingAuthorizationAmountDetails>, ) -> Self
Detailed breakdown of amount components.
These amounts are denominated in currency and in the smallest currency unit.
How the card details were provided. Defaults to online.
Sourcepub fn currency(self, currency: impl Into<Currency>) -> Self
pub fn currency(self, currency: impl Into<Currency>) -> Self
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn fleet(self, fleet: impl Into<CreateIssuingAuthorizationFleet>) -> Self
pub fn fleet(self, fleet: impl Into<CreateIssuingAuthorizationFleet>) -> Self
Fleet-specific information for authorizations using Fleet cards.
Sourcepub fn fraud_disputability_likelihood(
self,
fraud_disputability_likelihood: impl Into<CreateIssuingAuthorizationFraudDisputabilityLikelihood>,
) -> Self
pub fn fraud_disputability_likelihood( self, fraud_disputability_likelihood: impl Into<CreateIssuingAuthorizationFraudDisputabilityLikelihood>, ) -> Self
Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.
Sourcepub fn fuel(self, fuel: impl Into<CreateIssuingAuthorizationFuel>) -> Self
pub fn fuel(self, fuel: impl Into<CreateIssuingAuthorizationFuel>) -> Self
Information about fuel that was purchased with this transaction.
Sourcepub fn is_amount_controllable(
self,
is_amount_controllable: impl Into<bool>,
) -> Self
pub fn is_amount_controllable( self, is_amount_controllable: impl Into<bool>, ) -> Self
If set true, you may provide amount to control how much to hold for the authorization.
Sourcepub fn merchant_amount(self, merchant_amount: impl Into<i64>) -> Self
pub fn merchant_amount(self, merchant_amount: impl Into<i64>) -> Self
The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the smallest currency unit.
Sourcepub fn merchant_currency(self, merchant_currency: impl Into<Currency>) -> Self
pub fn merchant_currency(self, merchant_currency: impl Into<Currency>) -> Self
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
Sourcepub fn merchant_data(
self,
merchant_data: impl Into<CreateIssuingAuthorizationMerchantData>,
) -> Self
pub fn merchant_data( self, merchant_data: impl Into<CreateIssuingAuthorizationMerchantData>, ) -> Self
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
Sourcepub fn network_data(
self,
network_data: impl Into<CreateIssuingAuthorizationNetworkData>,
) -> Self
pub fn network_data( self, network_data: impl Into<CreateIssuingAuthorizationNetworkData>, ) -> Self
Details about the authorization, such as identifiers, set by the card network.
Sourcepub fn risk_assessment(
self,
risk_assessment: impl Into<CreateIssuingAuthorizationRiskAssessment>,
) -> Self
pub fn risk_assessment( self, risk_assessment: impl Into<CreateIssuingAuthorizationRiskAssessment>, ) -> Self
Stripe’s assessment of the fraud risk for this authorization.
Sourcepub fn verification_data(
self,
verification_data: impl Into<CreateIssuingAuthorizationVerificationData>,
) -> Self
pub fn verification_data( self, verification_data: impl Into<CreateIssuingAuthorizationVerificationData>, ) -> Self
Verifications that Stripe performed on information that the cardholder provided to the merchant.
Sourcepub fn wallet(self, wallet: impl Into<CreateIssuingAuthorizationWallet>) -> Self
pub fn wallet(self, wallet: impl Into<CreateIssuingAuthorizationWallet>) -> Self
The digital wallet used for this transaction.
One of apple_pay, google_pay, or samsung_pay.
Will populate as null when no digital wallet was utilized.
Sourceimpl CreateIssuingAuthorization
impl CreateIssuingAuthorization
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.