pub struct CreateIssuingAuthorizationRiskAssessmentCardTestingRisk {
pub invalid_account_number_decline_rate_past_hour: Option<i64>,
pub invalid_credentials_decline_rate_past_hour: Option<i64>,
pub level: CreateIssuingAuthorizationRiskAssessmentCardTestingRiskLevel,
}Expand description
Stripe’s assessment of this authorization’s likelihood of being card testing activity.
Fields
invalid_account_number_decline_rate_past_hour: Option<i64>The % of declines due to a card number not existing in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of card testing activity, meaning bad actors may be attempting different card number combinations to guess a correct one. Takes on values between 0 and 100.
invalid_credentials_decline_rate_past_hour: Option<i64>The % of declines due to incorrect verification data (like CVV or expiry) in the past hour, taking place at the same merchant. Higher rates correspond to a greater probability of bad actors attempting to utilize valid card credentials at merchants with verification requirements. Takes on values between 0 and 100.
level: CreateIssuingAuthorizationRiskAssessmentCardTestingRiskLevelThe likelihood that this authorization is associated with card testing activity. This is assessed by evaluating decline activity over the last hour.
Implementations
Sourceimpl CreateIssuingAuthorizationRiskAssessmentCardTestingRisk
impl CreateIssuingAuthorizationRiskAssessmentCardTestingRisk
pub fn new( level: impl Into<CreateIssuingAuthorizationRiskAssessmentCardTestingRiskLevel>, ) -> Self