pub struct CreateIssuingCard { /* private fields */ }Expand description
Creates an Issuing Card object.
Implementations
Sourceimpl CreateIssuingCard
impl CreateIssuingCard
Sourcepub fn new(
currency: impl Into<Currency>,
type_: impl Into<IssuingCardType>,
) -> Self
pub fn new( currency: impl Into<Currency>, type_: impl Into<IssuingCardType>, ) -> Self
Construct a new CreateIssuingCard.
Sourcepub fn cardholder(self, cardholder: impl Into<String>) -> Self
pub fn cardholder(self, cardholder: impl Into<String>) -> Self
The Cardholder object with which the card will be associated.
Sourcepub fn exp_month(self, exp_month: impl Into<i64>) -> Self
pub fn exp_month(self, exp_month: impl Into<i64>) -> Self
The desired expiration month (1-12) for this card if specifying a custom expiration date.
Sourcepub fn exp_year(self, exp_year: impl Into<i64>) -> Self
pub fn exp_year(self, exp_year: impl Into<i64>) -> Self
The desired 4-digit expiration year for this card if specifying a custom expiration date.
Sourcepub fn expand(self, expand: impl Into<Vec<String>>) -> Self
pub fn expand(self, expand: impl Into<Vec<String>>) -> Self
Specifies which fields in the response should be expanded.
Sourcepub fn financial_account(self, financial_account: impl Into<String>) -> Self
pub fn financial_account(self, financial_account: impl Into<String>) -> Self
The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.
Sourcepub fn lifecycle_controls(
self,
lifecycle_controls: impl Into<CreateIssuingCardLifecycleControls>,
) -> Self
pub fn lifecycle_controls( self, lifecycle_controls: impl Into<CreateIssuingCardLifecycleControls>, ) -> Self
Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our documentation for more details.
Sourcepub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
pub fn metadata(self, metadata: impl Into<HashMap<String, String>>) -> Self
Set of key-value pairs that you can attach to an object.
This can be useful for storing additional information about the object in a structured format.
Individual keys can be unset by posting an empty value to them.
All keys can be unset by posting an empty value to metadata.
Sourcepub fn personalization_design(
self,
personalization_design: impl Into<String>,
) -> Self
pub fn personalization_design( self, personalization_design: impl Into<String>, ) -> Self
The personalization design object belonging to this card.
Sourcepub fn pin(self, pin: impl Into<EncryptedPinParam>) -> Self
pub fn pin(self, pin: impl Into<EncryptedPinParam>) -> Self
The desired PIN for this card.
Sourcepub fn replacement_for(self, replacement_for: impl Into<String>) -> Self
pub fn replacement_for(self, replacement_for: impl Into<String>) -> Self
The card this is meant to be a replacement for (if any).
Sourcepub fn replacement_reason(
self,
replacement_reason: impl Into<CreateIssuingCardReplacementReason>,
) -> Self
pub fn replacement_reason( self, replacement_reason: impl Into<CreateIssuingCardReplacementReason>, ) -> Self
If replacement_for is specified, this should indicate why that card is being replaced.
Sourcepub fn second_line(self, second_line: impl Into<String>) -> Self
pub fn second_line(self, second_line: impl Into<String>) -> Self
The second line to print on the card. Max length: 24 characters.
Sourcepub fn shipping(self, shipping: impl Into<CreateIssuingCardShipping>) -> Self
pub fn shipping(self, shipping: impl Into<CreateIssuingCardShipping>) -> Self
The address where the card will be shipped.
Sourcepub fn spending_controls(
self,
spending_controls: impl Into<CreateIssuingCardSpendingControls>,
) -> Self
pub fn spending_controls( self, spending_controls: impl Into<CreateIssuingCardSpendingControls>, ) -> Self
Rules that control spending for this card. Refer to our documentation for more details.
Sourcepub fn status(self, status: impl Into<CreateIssuingCardStatus>) -> Self
pub fn status(self, status: impl Into<CreateIssuingCardStatus>) -> Self
Whether authorizations can be approved on this card.
May be blocked from activating cards depending on past-due Cardholder requirements.
Defaults to inactive.
Sourceimpl CreateIssuingCard
impl CreateIssuingCard
Sourcepub async fn send<C: StripeClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub async fn send<C: StripeClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response.
Sourcepub fn send_blocking<C: StripeBlockingClient>(
&self,
client: &C,
) -> Result<<Self as StripeRequest>::Output, C::Err>
pub fn send_blocking<C: StripeBlockingClient>( &self, client: &C, ) -> Result<<Self as StripeRequest>::Output, C::Err>
Send the request and return the deserialized response, blocking until completion.