pub struct CreateIssuingCardLifecycleControlsCancelAfter {
pub payment_count: u64,
}Expand description
Cancels the card after the specified conditions are met.
Fields
payment_count: u64The card is automatically cancelled when it makes this number of non-zero payment authorizations and transactions. The count includes penny authorizations, but doesn’t include non-payment actions, such as authorization advice.
Implementations